function [DataCube,BiasCube, deep, ccdName] = ...
    Read_DataCube_Dotii_fits(theList,sn, debug )
%   Read the  bidimentional fits data files of the same field [DOTII]
%   Usage [DataCube, BiasCube, deep]=Read_DataCube_Dotii_fits(theList,sn, debug )
%
%
%
%BH July 2021


% first extract the Data Science Area and the 

ccdName=cell(sn,1);
scArea=readHDR(theList{1}(1,:),'DATASEC','[%d:%d,%d:%d]');
biasArea=readHDR(theList{1}(1,:),'BIASSEC','[%d:%d,%d:%d]');
ccdName{1}=readHDR(theList{1}(1,:),'CCD_NAME','%s');

scRows=scArea(4)-scArea(3)+1;
scCols=scArea(2)-scArea(1)+1;
scSize=scRows*scCols;
biasRows=biasArea(4)-biasArea(3)+1;
biasCols=biasArea(2)-biasArea(1)+1;

%due  the original fits is BITPIX=16 and BZERO=32768 I use a signed integer of
%2 Bytes
DataCube=int16(zeros(scRows , scCols , sn));
BiasCube=int16(zeros(biasRows , biasCols , sn));

DataCube(:,:,1)=fitsread(char(theList{1}(1,:)), 'PixelRegion', { [scArea(3) scArea(4) ], [ scArea(1) scArea(2)]});
BiasCube(:,:,1)=fitsread(char(theList{1}(1,:)), 'PixelRegion', { [biasArea(3) biasArea(4) ], [ biasArea(1) biasArea(2)]});
deep=1;
if debug
             fprintf('\nDebug: Filename [%d]:%s',deep,char(theList{1}(deep,:)));
             fprintf('\nDebug: Data Science at: [%d:%d,%d:%d]', scArea(1), scArea(2), scArea(3), scArea(4));
             fprintf('\nDebug: Data Bias  at: [%d:%d,%d:%d]', biasArea(1), biasArea(2), biasArea(3), biasArea(4));  
             fprintf('\nDebug: CCD Name [%d]: %s \n', 1,char(ccdName(1)));
end

for nimage=2:sn
    deep=deep+1;
    
    scAreaT=readHDR(theList{1}(nimage,:),'DATASEC','[%d:%d,%d:%d]');
    scRowsT=scAreaT(4)-scAreaT(3)+1;
    scColsT=scAreaT(2)-scAreaT(1)+1;
    
    
    if scRowsT ~= scRows
        
        fprintf('Warning: the  image [%d] %s has differente  data science dimention\n', nimage, theList{1}(nimage,:));
        fprintf('Warning: Spected [%d X %d ]  and I see  [%d X %d ] \n', ...
         scRows, scCols,  scRowsT, scColsT);
         fprintf('Warning: Removed from the analysis....\n');
         deep=deep-1;
    elseif scColsT ~= scCols
     
        fprintf('Warning: the  image  [%d]  %s has differente  dimention\n', nimage, theList{1}(nimage,:));
        fprintf('Warning: Spected [%d X %d ]  and i see  [%d X %d ] \n', ...
           ImageSizeCube(1,1),   ImageSizeCube(2,1), ImageSizeCube(1,deep),  ImageSizeCube(2,deep));
         fprintf('Warning: Removed from the analysis...\n');
         deep=deep-1;
    else
        ccdName{deep}=readHDR(theList{1}(nimage,:),'CCD_NAME','%s');
         DataCube(:,:,deep)=fitsread(char(theList{1}(nimage,:)),  'PixelRegion',  { [scArea(3) scArea(4) ], [ scArea(1) scArea(2)]} );
         BiasCube(:,:,deep)=fitsread(char(theList{1}(nimage,:)),  'PixelRegion',   {[biasArea(3) biasArea(4) ], [ biasArea(1) biasArea(2)]});
         
         if debug
             fprintf('\nDebug: Filename [%d]:%s',deep,char(theList{1}(nimage,:)));
             fprintf('\nDebug: Data Science at: [%d:%d,%d:%d]', scArea(1), scArea(2), scArea(3), scArea(4));
             fprintf('\nDebug: Data Bias  at: [%d:%d,%d:%d]', biasArea(1), biasArea(2), biasArea(3), biasArea(4));
             fprintf('\nDebug: CCD Name [%d]: %s \n', deep,ccdName{deep});
         end
         
    end

 

end


