function [ ...
   objCentroidF,...   %Object Centroid (ox,oy)
   objEccF,...            % Object eccentricity
   objAreaF, ...        %Area of object
   objBoxF ...           % rectangular region of the object
   ] = detectAsteroide_runV2( ...
    Data,...                 %sum&shift image
    facStd,...             %standar deviation factor
    radius,...              % minimum search asteroid radius 
    eccentricity ...    % maximum asteroid eccentricity
    )
%Detection of candidate asteroids from an image where the 
% add&shift operator was applied to the data cube at a certain speed.
% INPUT 
%   Data: Image resulted from the sum & shift of the data cube for a 
%         particular velocity.
%   facStd: standar deviation factor
%   radius: minimum search asteroid radius  
%   eccentricity: maximum asteroid eccentricity
%
%OUTPUT
%   objVelocityF: Object Velocity (ovx,ovy)
%   objCentroidF:   Object Centroid (ox,oy)
%   objCentrodC: Corrected postion of Centroid(ox,oy)-origin(x,y)
%   objEccF: Object eccentricity
%   objAreaF:  Area of object
%   objBoxF: rectangular region of the object
% BHV Nov 2021

 [A,minA,factA]=normalizeData_param(Data,'log');

%over Raw Image
a=mean(A(:));
b=std(A(:));
u1=a+facStd*b; % low valud above "facStd" of std
if (u1 > 0.9 )
    u1=0.9;
end

B=A>u1;

morfR=strel('disk',round(radius),0);
C=imopen(B,morfR);

minBlobArea=round(pi*radius^2);
maxBlobArea=round(50*pi*radius^2);
maxBlobCount=5000;
theBlob=vision.BlobAnalysis('MinimumBlobArea',minBlobArea,...
    'MaximumBlobArea',maxBlobArea,'MaximumCount',maxBlobCount, ...
    'EccentricityOutputPort', 1);

[objArea,objCentroid,objBox,objEcc]=step(theBlob,C);
numObj=numel(objArea);
finalObj=0;
for ii=1:numObj
    if (objEcc(ii) <  eccentricity && objEcc(ii) >= 0 )
        finalObj=finalObj+1;
        objAreaF(finalObj)=objArea(ii); 
        objCentroidF(finalObj,:)=objCentroid(ii,:);
        objBoxF(finalObj,:)=objBox(ii,:);
        objEccF(finalObj)=objEcc(ii);
    end
end

% If no object found put -1 in all output variables
if (finalObj == 0)
     objAreaF=-1;
     objCentroidF=-1;
      objBoxF=-1;
      objEccF=-1;
end



end

