function [ objArea,objCentroid,objBox, numObj,finalThresh] = findPointsDDoti( ...
    theImg, ...
    thresh, ...
    threshDev, ...
    radius, ...
    minBlobArea, ...
    maxBlobArea, ...
    nPoints, ...
    minPoints, ...
    maxPoints,...
    nameFile, ...
    debug)
% Find control star position for alling process
%   Usage:   [ objArea,objCentroid,objBox, numObj] = findPoints( theImg,  thresh,  radius,  minBlobArea, ...
 %                   maxBlobArea, nameFile, debug)
 %Input:
 %theImg: 2D Image
 %thresh: Threshold real number between (0,1) 
 %threshDev: maximun threshold deviation +/- 0.1 
 %radius: for morfological circular mask
 %threshDev
 %minBlobArea: minimum area of the detect disk
 %maxBlobArea: maximum area of the detect disk
 %nPoints: desired point found
 %minPoints: minimum  numbers of point. 6 is the hard minima
 %maxPoints: maximum numbers of point. 45 point is the hard max
 %nameFile: Name file to be depicted on the figures when the debug is
 %                    actived
 %debug: level of verbosity (0: no verbosity)
 %
 %Output
 %objArea: Area of the detected  star position
 %objCentroid: Centroid (X,Y) of the detected  star position
 %objBox: The box of the  detected  star position
 %numObj: Number of the detected objects 
 %finalThresh: Final theshold
 %
 %May 2021
 % BHV

 theImgL=log(theImg);
  fact=1/(max(theImgL(:))-min(theImgL(:)));
  themin=min(theImgL(:));
  theImgNor=(theImgL - themin).*fact;
  
  maxThresh=thresh+abs(threshDev);
  minThresh=thresh-abs(threshDev);
  if maxPoints>45
      maxPoints=45;
  end
  if minPoints < 6
      minPoints =6;
  end
  
 maxIter=0;
 finalThresh=thresh;
 while (maxIter < 250)
     
     maxIter=maxIter+1;
     
    theImg_A=theImgNor>finalThresh;
    morf_r2=strel('disk',radius,0);
    theImg_B=imopen( theImg_A,morf_r2);
  
    theBlob=vision.BlobAnalysis('MinimumBlobArea',minBlobArea,...
       'MaximumBlobArea',maxBlobArea, 'MaximumCount',50);
   
       [objArea,objCentroid,objBox]=step(theBlob,theImg_B);
        numObj=numel(objArea);
        
        
        if (numObj >  maxPoints)
            minThresh=finalThresh;
            delta=(maxThresh-finalThresh)/2;
            finalThresh=finalThresh+delta;
        elseif (numObj < minPoints)
            maxThresh=finalThresh;
            delta=(finalThresh-minThresh)/2;
            finalThresh=finalThresh-delta;
        else
            break;
        end
      
 end     
 
  [objArea, theIdx]=sort(objArea,'descend');
  objCentroid=objCentroid(theIdx,:);
  objBox=objBox(theIdx,:);
  
  if numObj>nPoints
      objArea=objArea(1:nPoints);
      objCentroid=objCentroid(1:nPoints,:);
      objBox=objBox(1:nPoints,:);
      numObj=nPoints;
  end
  
   
   if debug
       
       if debug == 3
       figure(1)
       %subplot(1,3,1);
        imshow(theImgNor); 
        title('Image');
        c = colorbar('southoutside');
        c.Label.String = 'log';
        pause(1);
        
        figure(2)
        %subplot(1,3,2);
        imshow(theImg_A); 
        t=sprintf('Threshold: %4.2f',finalThresh);
        title(t);
        c = colorbar('southoutside');
        c.Label.String = 'log';
        pause(1);
        
         figure(3)
        %subplot(1,3,3);
        imshow(theImg_B); 
        t=sprintf('Morfoligical disk r=%d',radius);
        title(t);
        c = colorbar('southoutside');
        c.Label.String = 'binary';
        pause(1);
        
        

       end
       
        fprintf('\n\t Points found:\n');
        fprintf(' \t Name: %s\n',char(nameFile));
        fprintf(' \t Threshold: %6.4f ; Iteretios: %d\n',finalThresh,maxIter);
        fprintf(' \t Disk params [radius,minArea,maxArea]: %6.2f %6.2f  %6.2f \n',radius, minBlobArea,maxBlobArea);
        fprintf(' \t Op: P[j] Centroide\n');
        for i=1:numObj
                fprintf('\t [%d]: P%d (%6.2f, %6.2f) ,Area (%6.2f) \n',i,i,objCentroid(i,1), objCentroid(i,2), objArea(i));
        end
       
       
        if debug == 2
          figure(4)
          delta=15;
          bboxOut_2(:,1)=objBox(:,1)-delta;
           bboxOut_2(:,2)=objBox(:,2)-delta;
           bboxOut_2(:,3)=objBox(:,3)+2*delta;
           bboxOut_2(:,4)=objBox(:,4)+2*delta;
           imgShape= insertShape(theImgNor,'rectangle',bboxOut_2,'Linewidth',14,'Color',[255 0 0]);
           imshow(imgShape);
        
           delta2=delta+10;
           textPos=round(objCentroid+delta2);
           imgSize=size(theImg);
           xmax=imgSize(2);
           ymax=imgSize(1);
           for i=1:numObj
            if(textPos(i,1) > (xmax -50))
                 textPos(i,1)=round(objCentroid(i,1)-(2*delta2));
            end
            if(textPos(i,2) > (ymax -20))
              textPos(i,2)=round(objCentroid(i,2)-(2*delta2));
            end
           end
           
           text_objstr = cell(numObj,1);
           for i=1:numObj
                text_objstr{i}=['P[' num2str(i,'%d') ']' ];
           end
   
           imgShapeText=insertText(imgShape,  textPos, text_objstr, ...
            'TextColor','yellow','FontSize',100,'BoxColor' ,[1 1 1],...
            'BoxOpacity',0);
           imshow(imgShapeText);
           t=sprintf('%s ',char(nameFile));
           t2=sprintf('Points found: %d',numObj);
           title([t,t2],'Interpreter', 'none');
           pause(1);
        end  
   end
   
end

