function [ theMask,objCentroid, objArea,objBox, nData] = maskMedian( Data,theRegions,timesBackground, radius, debug)
% Compute the mask of a image (Data) with N times greate that the background according the selected regions
% Usage:  [ theMask ] = maskMedian( Data,theRegions,timeBackground, debug)
%Input:
% Data:The Median image
%Regions: Sky regions (Xcenter, Y Center, Width, Hight)
%timeBackground: Pixels over N  times the sky background 
% radius: Radius of the dilation mask
%debug:  0: no debug; 1: some basic info; 2: more vervosity
%
%Output:
% theMask: the logical mask
%
%
% BH Jun 2021


[skMedian,~,~]=skyAdjustOnlyStats(Data,theRegions);

Data(Data < skMedian)=skMedian;
nData=Data;
theImgL=log(Data);
fact=1/(max(theImgL(:))-min(theImgL(:)));
themin=min(theImgL(:));
theImgNor=(theImgL - themin).*fact;

if(timesBackground <= 0)
    % 2.5 times the sky background
    newThresh= (log(2.5*skMedian)-themin)*fact;
else
    newThresh=(log(timesBackground*skMedian)-themin)*fact;
end

theImg_A=theImgNor>newThresh;
 % Dilate te Image with a circular morfological mask with r=1pix
 % The intention is capture the entire  PSF 
 %  radius=3;
 morf_r2=strel('disk',radius,0); 
 theMask=imdilate(theImg_A, morf_r2);
 

    minBlobArea=round(pi*(radius)^2); 
    maxBlobArea=2500;
    maxBlobCount=5000;
    theBlob=vision.BlobAnalysis('MinimumBlobArea',minBlobArea,...
          'MaximumBlobArea',maxBlobArea,'MaximumCount',maxBlobCount);   
   
    [objArea,objCentroid,objBox]=step(theBlob,theMask);
    [objArea, theIdx]=sort(objArea,'descend');
    objCentroid=objCentroid(theIdx,:);
    objBox=objBox(theIdx,:);
 
   if debug
     if debug == 2
       figure(1)
       subplot(1,3,1);
        imshow(theImgNor); 
        title('Median Image');
        c = colorbar('southoutside');
        c.Label.String = 'log';
        
        subplot(1,3,2);
        imshow(theImg_A); 
        t=sprintf('Median Image: Threshold: %4.2f',newThresh);
        title(t);
        c = colorbar('southoutside');
        c.Label.String = 'binary';
        
        subplot(1,3,3);
        imshow(theMask); 
        t=sprintf('Morfoligical dilation disk r=%d',radius);
        title(t);
        c = colorbar('southoutside');
        c.Label.String = 'binary';
        pause(1);
     end
      
         numObj=numel(objArea);
        delta=2;
        bboxOut_2(:,1)=objBox(:,1)-delta;
        bboxOut_2(:,2)=objBox(:,2)-delta;
        bboxOut_2(:,3)=objBox(:,3)+2*delta;
        bboxOut_2(:,4)=objBox(:,4)+2*delta;
        imgShape= insertShape(theImgNor,'rectangle',bboxOut_2,'Linewidth',2,'Color',[255 0 0]);
        figure(2);
        pause(1);
        imshow(imgShape);
        t=sprintf('Number of starts to be masked:  %d',numObj); 
        title(t);
 end
        
end

