function [ newCube ] = patchStar( Cube, theReg, bgFactor, bgFlag, radius, theType, debug )
%  Improved data cube using background regions above the median, in addition 
%  to calculating a star mask to remove them in analysis
%  Usage:  [ newCube ] = DofMbg( Cube, theReg, bgFactor, bgFlag, debug )
%
%Input:
%Cube: Data Cube
%theReg: Regions to extract the median of the background sky
%bgFactor:  background factor for detecting any star
%bgFlag: backgroung flag
% 0: only replace the mask with the median of the sky background  in
%      the new cube
% 1: same as the previous  one, and for values of the data cube smaller  than 
%       the median of the sky background they will be replaced by it.
% radius: Radius of the dilation mask
% debug: verbosity 
%
% jun 2021
%BH
outHDR=theType;
opt={'Background','Std'}; 
TF = strcmpi(opt,theType);



Median=onlyMedian(Cube);
[rtot,ctot,deep]=size(Cube);
newCube=zeros(rtot,ctot,deep,'like',Cube);

[theMask, ~, ~, ~]=maskMedian(Median,theReg,bgFactor,radius,debug);

%newCube=DofM;

for ii=1:deep
     A=Cube(:,:,ii);
    [skMedian,~,~]=skyAdjustOnlyStats(A,theReg);
    A(theMask)=skMedian;
    if bgFlag
        A(A < skMedian)=skMedian;
    end
    newCube(:,:,ii)=A;
end

end

