function [ newCube ] = patchStar_File( Cube, theMask, theReg, theType, maskTo, bgFlag )
%  Improved data cube using background regions above the median, in addition 
%  to calculating a star mask to remove them in analysis
%  Usage:  [ newCube ] = patchStar_File( Cube, theMask, theVal, debug )
%
%Input:
%Cube: Data Cube
%theMask: Binary Mask
%theReg: Region Box Positions to define the Backgroud
%theType:  Use Background or Std
%maskTo: The mask must be apply to:
%               DoffM: Diferences over the Median
%               Raw:  Raw data cube
%bgFlag: backgroung T
% 0: only replace the mask with the median of the sky background  in
%      the new cube
% 1: same as the previous  one, and for values of the data cube smaller  than 
%       the median of the sky background they will be replaced by it.

% jun 2021
%BH


[~,~,deep]=size(Cube);

opt={'Background','Std'}; 
TF = strcmpi(opt,theType);

if ~TF(1) &&   ~TF(2)
     fprintf("Error: Background estimator   unknow option (%s) . \n\tWrite  Background or Std  \n\tAboorting ..\n",...
    theType );
    newCube =[];
     return;
end

opt2={'DoffM','Raw'}; 
TF2 = strcmpi(opt2,maskTo);
if ~TF2(1) &&   ~TF2(2)
     fprintf("Error: Mask must be apply to  unknow option (%s) . \n\tWrite  ... DoffM or Raw \n\tAboorting ..\n",...
     maskTo);
    newCube =[];
     return;
end

if (TF2(1))
   [Cube,~]=diffOfMedian(Cube);
end

newCube=zeros(size(Cube),'like',Cube);

for ii=1:deep
     A=Cube(:,:,ii);
     if TF(1)
        [skVal,~,~]=skyAdjustOnlyStats(single(A),theReg);
     else
         [~,skVal,~]=skyAdjustOnlyStats(single(A),theReg);
     end
         
    A(theMask)=skVal;
    if bgFlag
        A(A < skVal)=skVal;
    end
    newCube(:,:,ii)=A;
end

end

