function [ theSum, minCoor,maxCoor] = sumShift_Gaps( theCube, pv, MJD, t0, sflag )
%sumShift_Gaps sum and shift the data cube according to some frame pixel
%velocity (pv). Also include posibles gaps produced from non-uniform time
%adquisitions of the data and the postions of the pivot image can be at the Beging,
%the Middle or the End of the cube.
%
% Usage: [ theSum, minCoor,maxCoor] = sumShift_Gaps( theCube, pv, MJD, t0, sflag )
%
% Input
%  theCube: data cube (r,c,deep)
%  pv: velocity pixel  vector [vx,vy]
%  MJD: Julian date from original header
%  t0: ['Begin'|'Middle'|'End'] Positions of the pivot image.
%  sflag:  Output Size
%     0: Same that the original image
%     1: Only usable area
%
% Output:
%  theSum: Summed & Shifted Image
%  minCoor: Origin coordinate (Xmin,Ymin) of the usuable area. Column vector
%  maxCoor: The max coordinate (Xmax, Ymax) of the usuable area. Column Vector
%
%Sep 2021
%BH
%Nov 2022
% - include position of the pivot image
% - the usuable area is calculated from other function

opt={'Begin','Middle','End'}; 
TF = strcmpi(opt,t0);

if ~TF(1) &&   ~TF(2) &&   ~TF(3) 
     fprintf("Warning: The pivot position t0 [%s] differ off [Begin|Middle|End]\n", t0);
     fprintf("Warning: Assumming the Middle.....\n");
    TF(2)=TRUE;  
end


[rtot,ctot,deep]=size(theCube);
theSumC=zeros(rtot,ctot,deep,'like',theCube);
[vShift_A] = pixvecVelocityGaps( MJD,pv,[rtot,ctot,deep]);

if TF(1)
    vShift=vShift_A;
elseif TF(3)
    tf=vShift_A(size(vShift_A,1),:);
    vShift=vShift_A-tf;
else
    tm=vShift_A(round(size(vShift_A,1)/2.),:);
    vShift=vShift_A-tm;
end
[minCoor,maxCoor] = usuableArea(vShift,[rtot,ctot]);

parfor i=1:deep
    theSumC(:,:,i)=noncircshift(theCube(:,:,i), vShift(i,:));
end

A=single(sum(theSumC,3));
 
if sflag
    theSum=A(minCoor(2):maxCoor(2),  minCoor(1): maxCoor(1));
else
    theSum=A;
end

end

