function [ theV] = try_velocities(velX,velY )
%Generate a velocity vector according (Vx_ini, Vx_end, Delta_Vx),
%(Vy_ini, Vy_end, Delta_Vy).
%   Usage [ theV] = try_velocities(velX,velY )
%
%Input:
%   velX :The frame velocity over X axis (VXini,VXend,VXdelta)
%   velY :The frame velocity over Y axis (VYini,Vyend,VYdelta)
%
%Output:
% theV(x_i,y_i): Final vector
%
% BHV
%Dec 2021
% Include range velocity error. If Vini > Vend and Delta > 0
%  change Delta=-Delta 
%  BHV Nov 2022

nx=abs(floor( (velX(2)-velX(1)) / velX(3) ))+1;
a=rem( velX(2)-velX(1) ,  velX(3));
if a ~= 0
    nx=nx+1;
end

% check some error in the limits
b=1;
if (velX(1)> velX(2) && velX(3) > 0 )
    b=-1;
    fprintf('Warning try_velocity: range X-axis mismatch, inicial velocity [%d] > final velocity [%d]\n', ...
        velX(1),velX(2));
    fprintf('Warning try_velocity: asume decrement delta [%d]\n', ...
        b*velX(3));
end

Vx=linspace(velX(1),velX(1)+(nx-1)*velX(3)*b,nx);

ny=abs(floor( (velY(2)-velY(1)) /velY(3) )) +1;
a=rem( velY(2)-velY(1) ,  velY(3));
if a ~= 0
    ny=ny+1;
end

b=1;
if (velY(1)> velY(2) && velY(3) > 0 )
    b=-1;
    fprintf('Warning try_velocity: range Y-asix mismatch; inicial velocity [%d] > final velocity [%d]\n', ...
        velY(1),velY(2));
    fprintf('Warning try_velocity: asume decrement delta [%d]\n', ...
        b*velY(3));
end


Vy=linspace(velY(1),velY(1)+(ny-1)*velY(3),ny);

[A,B] = meshgrid(Vx,Vy);
C=cat(2,A,B);
theV=reshape(C,[],2);
%theV=theV.';


end

