function [  ] = wfits_AL(...
    Data, ... % the Image 
    originalFile, ... %Original File Name
    newName, ... %  New  alligned file name with path
    onlyName, ... % previus with out path
    refImageName, ... % Reference Image Name
    minCoor,...   %  Usuable Area (x,y)
    maxCoor,...   % Usuable Area (x,y)
    RM, ...             % Rotations Matrix
    TV, ...               % Translation Vector
    deep, ...           % number of deep data Cub
    threshold, ...  %Theshold use for binarize
    theScale, ...     %Image scale user for binarize
    theRadius, ...     % Radius of the circular prototype mask
    theMinArea, ... %Minumim Circular area
    theMaxArea, ... %Maximum Circular area
    theCPoint, ...   %Number of the common control points used
    debug) 
%Write the Data in a fits file format. Also include the header value
%   Detailed explanation goes here A
%
%
%
%
% BH Aug 2021

val1= readHDR(originalFile,'DATE-OBS','%s');
val2= readHDR(originalFile,'MJD','%d');
val3= readHDR(originalFile,'CCD_NAME','%s');
val4= readHDR(originalFile,'EXPTIME','%d');


import matlab.io.*

[filepath, ~, ~] = fileparts(newName);
if strcmp(filepath,'.') %Grrrrr matlab can not manage the format "./file"
    if exist(char(onlyName),'file') == 2
      fprintf('Warning: the file [%s] exist. I remove it..',char(newName));
      delete(newName);
    end
else
    if exist(char(newName),'file') == 2
        fprintf('Warning: the file [%s] exist. I remove it..',char(newName))'
        delete(newName);
    end
end
    
fitswrite(Data,char(newName));
% first remove the inserted matlab comments
fptr= fits.openFile(char(newName),'readwrite');
fits.writeComment(fptr,'Aligned data cube allgoritms, TAOSII team');
fits.writeComment(fptr,'Authors: BHV/JSS/ESM');
dt=datetime('now');
sdt= sprintf('Date of Run: %s',dt);
fits.writeComment(fptr,sdt);

% New file Name
fits.writeKey(fptr,'ANAME',char(onlyName),'Add  [BrAL...] postfix');
fits.writeComment(fptr,'Br: Bias removed; AL: Aligned; 2: 2nd aligned; U: usuable area');
fits.writeComment(fptr,'S: Sky background without trend; M: Median removed (without star)');
fits.writeComment(fptr,'P: Stars patch');


fits.writeKey(fptr,'AREFNAME',char(refImageName),'Reference image name');
% Usable Area affter allign
% min/max Coor is in Image  Coord that mean
%that axisX is the seconde component (the columns)  and
% the axisY is firts component  (the row) 
%UAREA=[minX:maxX,minY:masY] format
str_uArea=sprintf('[%d:%d,%d:%d]', minCoor(1),maxCoor(1),...
    minCoor(2),maxCoor(2));
fits.writeKey(fptr,'AAREA',str_uArea,'Usuable area');

% Rigid Transformation Rotation Matrix and Translation Vector 
fits.writeKey(fptr,'ACD1_1',single(RM{1}(1,1)),'Rotation matrix');
fits.writeKey(fptr,'ACD1_2',single(RM{1}(1,2)),'Rotation matrix');
fits.writeKey(fptr,'ACD2_1',single(RM{1}(2,1)),'Rotation matrix');
fits.writeKey(fptr,'ACD2_2',single(RM{1}(2,2)),'Rotation matrix');
fits.writeKey(fptr,'ATV1',single(TV{1}(1)),'Translation vector x-axis');
fits.writeKey(fptr,'ATV2',single(TV{1}(2)),'Translation vector y-axis ');

% Parameters of the deteted control points for alligned process
fits.writeKey(fptr,'ADEEP',int32(deep),'Data cube depth');
fits.writeKey(fptr,'ATHRE',single(threshold),'Threshold used to binarize');
fits.writeKey(fptr,'ASCL',char(theScale),'Image scale used LOG|LINEAR');
fits.writeKey(fptr,'ARADIUS',int32(theRadius),'Disk prototype mask radius');
fits.writeKey(fptr,'AMINA',single(theMinArea),'Minumim circular area');
fits.writeKey(fptr,'AMAXA',single(theMaxArea),'Maximum circular area');
fits.writeKey(fptr,'APOINT',int32(theCPoint),'Number of common control points used');

fits.writeKey(fptr,'DATE-OBS',val1,'By original file');
fits.writeKey(fptr,'MJD',double(val2),'By original file');
fits.writeKey(fptr,'CCD_NAME',val3,'By original file');
fits.writeKey(fptr,'EXPTIME',single(val4),'By original file');


fits.closeFile(fptr);

if debug
    fitsdisp(char(newName),'mode','full');
end

end

